<div class="object-detail-inclusion {{ object.class_name.lower }}-detail-inclusion">
    {% block content %}
        {% if object.image %}
            <img src="{{ object.image_detail_url }}" />
        {% endif %}
        {% if object.description %}
            <div class="description">
                {{ object.description|linebreaks }}
            </div>
        {% endif %}
    {% endblock %}    
    <div class="clear"></div>
</div>
