{% load jmbo_template_tags i18n %}

<img src="{{ object.get_thumbnail_url }}" alt="{{ object.title }}" />

<div class="title">
    <a href="{{ object.get_absolute_url }}">{{ object.title|truncatewords_html:10 }}</a>
</div>

{{ object.description|truncatewords_html:10 }}
