{% load i18n %}

<div class="object-footer">    

    <div class="sharing">
        <div class="facebook">
            <a href="http://www.facebook.com/sharer.php?u=http{% if request.is_secure %}s{%endif %}://{{ request.META.HTTP_HOST }}{{ object.get_absolute_url|iriencode }}&t={{ object.title|iriencode }}"
               target="blank">
               <img src="{{ STATIC_URL }}jmbo/images/facebook_share.png" alt="{% trans "Share via Facebook" %}" />{% trans "Share" %}
            </a>
        </div>
        <div class="twitter">
            <a href="http://www.twitter.com/share?url=http{% if request.is_secure %}s{%endif %}://{{ request.META.HTTP_HOST }}{{ object.get_absolute_url|iriencode }}"
               target="blank">
               <img src="{{ STATIC_URL }}jmbo/images/twitter_share.png" alt="{% trans "Share via Twitter" %}" />{% trans "Tweet" %}
            </a>
        </div>
    </div>

</div>    
