{% comment %}
1. Remove breadcrumbs.
2. First and last links.
{% endcomment %}

{% if page_obj.has_other_pages %}

    {% load jmbo_template_tags i18n %}
    <div class="pagination">
        {% if page_obj.has_previous %}
            <a href="{% smart_query_string 'page' 1 %}" class="first">&lsaquo;&lsaquo; {% trans "first" %}</a>
            <a href="{% smart_query_string 'page' page_obj.previous_page_number %}" class="prev">&lsaquo; {% trans "previous" %}</a>
        {% else %}
            <span class="disabled first">&lsaquo;&lsaquo; {% trans "first" %}</span>
            <span class="disabled prev">&lsaquo; {% trans "previous" %}</span>
        {% endif %}
        {% if page_obj.has_next %}
            <a href="{% smart_query_string 'page' page_obj.next_page_number %}" class="next">{% trans "next" %} &rsaquo;</a>
            <a href="{% smart_query_string 'page' page_obj.paginator.num_pages %}" class="last">{% trans "last" %} &rsaquo;&rsaquo;</a>
        {% else %}
            <span class="disabled next">{% trans "next" %} &rsaquo;</span>
            <span class="disabled last">{% trans "last" %} &rsaquo;&rsaquo;</span>
        {% endif %}
    </div>

{% endif %}
